@@ -8,7 +8,7 @@ import logging.config
 from yqdata.utils.opensearch import get_client
 import json
 
-def daily_basic(ts_code=None, trade_date = None, start_date=None, end_date=None):
+def daily_basic(ts_code='', trade_date = '', start_date=None, end_date=None, fields=''):
     """
     获取每日指标数据
     :param ts_code: 股票代码
@@ -19,9 +19,9 @@ def daily_basic(ts_code=None, trade_date = None, start_date=None, end_date=None)
     """
     logging.debug("get daily basic, ts_code: %s, trade_date: %s, start_date: %s, end_date: %s", ts_code, trade_date, start_date, end_date)
     query = []
-    if ts_code is not None:
+    if ts_code != '':
         query.append({"match": {"ts_code.keyword":  ts_code }})
-    if trade_date is not None:
+    if trade_date != '':
         query.append({"match": {"trade_date": trade_date}})
     if start_date is not None and end_date is not None:
         query.append({"range": {"trade_date": {"gte":  start_date, "lte":  end_date}}})
@@ -30,9 +30,10 @@ def daily_basic(ts_code=None, trade_date = None, start_date=None, end_date=None)
     elif start_date is None and end_date is not None:
         query.append({"range": {"trade_date": {"lte":  end_date}}})
 
-    print(query)
-    logging.info(json.dumps(query))
-    return get_client().search_by_condition(index='daily_basic', must=query, size=100000)
+    if fields != '' and isinstance (fields ,str):
+        fields = fields.split(',')
+
+    return get_client().search_by_condition(index='daily_basic', must=query, size=100000, fields=fields)
 
 if __name__ == '__main__':
-    print(daily_basic(ts_code='000001.SZ', trade_date='20190401'))
\ No newline at end of file
+    print(daily_basic(ts_code='300902.SZ', start_date='20191203', end_date='20210102', fields='ts_code,pe,pb'))
\ No newline at end of file
